Index: wp-content/themes/twentyeleven/inc/theme-options.php
===================================================================
--- wp-content/themes/twentyeleven/inc/theme-options.php	(revision 17844)
+++ wp-content/themes/twentyeleven/inc/theme-options.php	(working copy)
@@ -1,6 +1,6 @@
 <?php
 /**
  * Twenty Eleven Theme Options
  *
  * @package WordPress
  * @subpackage Twenty Eleven
@@ -8,14 +8,14 @@
  */
 
 /**
  * Properly enqueue styles and scripts for our theme options page.
  *
  * This function is attached to the admin_enqueue_scripts action hook.
  *
  * @since Twenty Eleven 1.0
  *
  * @param string $hook_suffix The action passes the current page to the function. We don't
  * 	do anything if we're not on our theme options page.
  */
 function twentyeleven_admin_enqueue_scripts( $hook_suffix ) {
 	if ( $hook_suffix != 'appearance_page_theme_options' )
@@ -55,7 +55,7 @@
 add_action( 'admin_init', 'twentyeleven_theme_options_init' );
 
 /**
  * Add our theme options page to the admin menu.
  *
  * This function is attached to the admin_menu action hook.
  *
@@ -63,8 +63,8 @@
  */
 function twentyeleven_theme_options_add_page() {
 	add_theme_page(
-		__( 'Theme Options', 'twentyeleven' ), // Name of page
-		__( 'Theme Options', 'twentyeleven' ), // Label in menu
+		__( 'Theme Settings', 'twentyeleven' ), // Name of page
+		__( 'Theme Settings', 'twentyeleven' ), // Label in menu
 		'edit_theme_options',                  // Capability required
 		'theme_options',                       // Menu slug, used to uniquely identify the page
 		'theme_options_render_page'            // Function that renders the options page
@@ -154,7 +154,7 @@
 	?>
 	<div class="wrap">
 		<?php screen_icon(); ?>
-		<h2><?php printf( __( '%s Theme Options', 'twentyeleven' ), get_current_theme() ); ?></h2>
+		<h2><?php printf( __( '%s Theme Settings', 'twentyeleven' ), get_current_theme() ); ?></h2>
 		<?php settings_errors(); ?>
 
 		<form method="post" action="options.php">
@@ -1,6 +1,6 @@
 <?php
 /**
- * Twenty Eleven Theme Options
+ * Twenty Eleven Theme Settings
  *
  * @package WordPress
@@ -8,14 +8,14 @@
 
 /**
- * Properly enqueue styles and scripts for our theme options page.
+ * Properly enqueue styles and scripts for our theme settings page.
  *
  * This function is attached to the admin_enqueue_scripts action hook.
@@ -8,14 +8,14 @@
  *
  * @param string $hook_suffix The action passes the current page to the function. We don't
- * 	do anything if we're not on our theme options page.
+ * 	do anything if we're not on our theme settings page.
  */
 function twentyeleven_admin_enqueue_scripts( $hook_suffix ) {
@@ -55,7 +55,7 @@
 
 /**
- * Add our theme options page to the admin menu.
+ * Add our theme settings page to the admin menu.
  *
  * This function is attached to the admin_menu action hook.
